import { EventEmitter, OnInit, AfterViewInit, OnDestroy, ElementRef, NgZone, OnChanges } from '@angular/core';
import { Subject } from 'rxjs';
import { InViewportDirective } from '@thisissoon/angular-inviewport';
import { ImageLoadedEvent } from '../shared/image-loaded-event.model';
import { Breakpoint } from '../shared/breakpoint.model';
import { ResponsiveImage, Size } from '../shared/image.model';
/**
 * A component that renders a `img` element with the correct image url
 * for the device size
 *
 * @example
 * ```html
 * <sn-image-loader
 *   [image]="image"
 *   [sizes]="sizes"
 *   imgClass="foo"
 *   (placeholderLoaded)="onPlaceholderLoad($event)"
 *   (imageLoaded)="onImageLoad($event)"
 *   alt="lorem ipsum">
 * </sn-image-loader>
 * ```
 * @dynamic
 */
export declare class ImageLoaderComponent implements OnInit, AfterViewInit, OnDestroy, OnChanges {
    private window;
    private ngZone;
    /**
     * URL of image for `img` element to display
     * @memberof ImageLoaderComponent
     */
    src: string;
    /**
     * srcset string for `img` element
     * @memberof ImageLoaderComponent
     */
    srcset: string;
    /**
     * Alt tag for image
     * @memberof ImageLoaderComponent
     */
    alt: string;
    /**
     * Classes to pass on to image element
     * @memberof ImageLoaderComponent
     */
    imgClass: string;
    /**
     * URL of image to preload using a dummy image element
     * @memberof ImageLoaderComponent
     */
    preloadSrc: string;
    /**
     * srcset value of retina image to preload using a dummy image
     * element
     * @memberof ImageLoaderComponent
     */
    preloadSrcset: string;
    /**
     * List of image breakpoints
     * @memberof ImageLoaderComponent
     */
    sizes: Breakpoint[];
    /**
     * Current size of image to display
     * @memberof ImageLoaderComponent
     */
    size: Size;
    /**
     * Set of images for different viewports
     *
     * @memberof ImageLoaderComponent
     */
    image: ResponsiveImage;
    /**
     * If true means the element is inside the browser viewport
     *
     * @memberof ImageLoaderComponent
     */
    inViewport: boolean;
    /**
     * Amount of time to wait after last event
     *
     * @memberof ImageLoaderComponent
     */
    debounce: number;
    /**
     * Completes on component destroy lifecycle event
     * use to handle unsubscription from infinite observables
     *
     * @memberof ImageLoaderComponent
     */
    ngUnsubscribe$: Subject<void>;
    /**
     * Reference to image element
     *
     * @memberof ImageLoaderComponent
     */
    img: ElementRef;
    /**
     * Reference to instance of inViewport directive instance
     *
     * @memberof ImageLoaderComponent
     */
    snInViewport: InViewportDirective;
    /**
     * If true it means the browser supports `srcset`
     * @memberof ImageLoaderComponent
     */
    supportsSrcSet: boolean;
    /**
     * Output for placeholder image loaded event.
     *
     * @memberof ImageLoaderComponent
     */
    placeholderLoaded: EventEmitter<ImageLoadedEvent>;
    /**
     * Output for full res image loaded event.
     *
     * @memberof ImageLoaderComponent
     */
    imageLoaded: EventEmitter<ImageLoadedEvent>;
    /**
     * If true means the image has not been loaded yet and
     * the placeholder image is currently displayed
     *
     * @memberof ImageLoaderComponent
     */
    loaded: boolean;
    /**
     * If true means the image has not been loaded yet and
     * the placeholder image is currently displayed
     *
     * @readonly
     * @memberof ImageLoaderComponent
     */
    readonly notLoaded: boolean;
    /**
     * Creates instance of component. Updates this.size
     * based on window width.
     *
     * @memberof ImageLoaderComponent
     */
    constructor(window: Window, ngZone: NgZone);
    /**
     * Set placeholder image as image on component init
     *
     * @memberof ImageLoaderComponent
     */
    ngOnInit(): void;
    /**
     * Subscribe to `resize` window event observable
     * and run callback
     *
     * @memberof ImageLoaderComponent
     */
    ngAfterViewInit(): void;
    /**
     * If element is in viewport preload image by setting the src
     * of the dummy image element.
     *
     * @memberof ImageLoaderComponent
     */
    onInViewportChange(inViewport: boolean): void;
    /**
     * On width change, determine if device has changed and
     * reset directive
     *
     * @memberof ImageLoaderComponent
     */
    onWidthChange(width: number): void;
    /**
     * Set image to placeholder image
     *
     * @memberof ImageLoaderComponent
     */
    setPlaceholder(): void;
    /**
     * Trigger image preload if element is within viewport
     * and hasn't been preloaded
     *
     * @memberof ImageLoaderComponent
     */
    preloadImage(): void;
    /**
     * When image has been preloaded set the src for the
     * main `img` element to replace the placeholder
     *
     * @memberof ImageLoaderComponent
     */
    onImagePreload(): void;
    /**
     *
     * @memberof ImageLoaderComponent
     */
    onImagePreloadError(): void;
    /**
     * When the main `img` element has loaded
     *
     * @memberof ImageLoaderComponent
     */
    onImageLoad($event: Event): void;
    /**
     * Trigger `ngUnsubscribe` complete on
     * component destroy lifecycle hook
     *
     * @memberof ImageLoaderComponent
     */
    ngOnDestroy(): void;
    /**
     * Trigger image preload on changes.
     * Prevents angular from reusing rendered image
     * after changes.
     *
     * @memberof ImageLoaderComponent
     */
    ngOnChanges(): void;
}
