import { NgZone, AfterViewInit, OnInit, OnDestroy, ChangeDetectorRef, ElementRef } from '@angular/core';
import { Subject } from 'rxjs';
import { InViewportDirective } from '@thisissoon/angular-inviewport';
import { Size } from '../../image-loader/shared/image.model';
import { Breakpoint } from '../../image-loader/shared/breakpoint.model';
import { ResponsiveVideo } from '../shared/video.model';
import { ImageLoadedEvent } from '../../image-loader/shared/image-loaded-event.model';
/**
 * A component that load a `video` element with the correct
 * video and poster for the device size
 *
 * @example
 * ```html
 * <sn-video-loader
 *   [sizes]="sizes"
 *   [video]="video"
 *   [loop]="true"
 *   [muted]="true"
 *   [autoplay]="true"
 *   [playsInline]="true"
 *   type="video/mp4"
 *   videoClass="video"
 *   posterClass="img">
 * </sn-video-loader>
 * ```
 *
 * @dynamic
 */
export declare class VideoLoaderComponent implements OnInit, AfterViewInit, OnDestroy {
    private window;
    private ngZone;
    private cdRef;
    /**
     * Videos to select from
     *
     * @memberof VideoLoaderComponent
     */
    video: ResponsiveVideo;
    /**
     * Current src value to set to video
     *
     * @memberof VideoLoaderComponent
     */
    src: string;
    /**
     * Alt tag for fallback image
     *
     * @memberof VideoLoaderComponent
     */
    alt: string;
    /**
     * If true the video will be set to loop
     *
     * @memberof VideoLoaderComponent
     */
    loop: boolean;
    /**
     * If true displays the video controls
     *
     * @memberof VideoLoaderComponent
     */
    controls: boolean;
    /**
     * If true the video will be muted
     *
     * @memberof VideoLoaderComponent
     */
    muted: boolean;
    /**
     * If true video should autoplay
     *
     * @memberof VideoLoaderComponent
     */
    autoplay: boolean;
    /**
     * If true the video will playinline rather then
     * in a modal window on iOS
     *
     * @memberof VideoLoaderComponent
     */
    playsInline: boolean;
    /**
     * Reference to inviewport directive instance
     *
     */
    snInViewport: InViewportDirective;
    /**
     * Reference to HTML Video element
     *
     * @memberof VideoLoaderComponent
     */
    videoEl: ElementRef;
    /**
     * List of breakpoints to select video from
     *
     * @memberof VideoLoaderComponent
     */
    sizes: Breakpoint[];
    /**
     * Current size of video to display
     * @memberof VideoLoaderComponent
     */
    size: Size;
    /**
     * Video type e.g. video/mp4
     *
     * @memberof VideoLoaderComponent
     */
    type: string;
    /**
     * If true means the element is inside the browser viewport
     *
     * @memberof VideoLoaderComponent
     */
    inViewport: boolean;
    /**
     * Amount of time to wait after last event
     *
     * @memberof VideoLoaderComponent
     */
    debounce: number;
    /**
     * Classes to pass on to video element
     * @memberof VideoLoaderComponent
     */
    videoClass: string;
    /**
     * Classes to pass on to image element
     * @memberof VideoLoaderComponent
     */
    posterClass: string;
    /**
     * Value for video poster property
     *
     * @memberof VideoLoaderComponent
     */
    poster: string;
    /**
     * Completes on component destroy lifecycle event
     * use to handle unsubscription from infinite observables
     *
     * @memberof VideoLoaderComponent
     */
    ngUnsubscribe$: Subject<void>;
    /**
     * If true means the video has not been loaded yet and
     * the placeholder video is currently displayed
     *
     * @memberof VideoLoaderComponent
     */
    loaded: boolean;
    /**
     * If true means the video has not been loaded yet and
     * the placeholder video is currently displayed
     *
     * @readonly
     * @memberof VideoLoaderComponent
     */
    readonly notLoaded: boolean;
    /**
     * Creates an instance of VideoLoaderComponent.
     * @memberof VideoLoaderComponent
     */
    constructor(window: Window, ngZone: NgZone, cdRef: ChangeDetectorRef);
    /**
     * Set poster before component renders to resolve an issue
     * with autoplay on safari browsers
     *
     * @memberof VideoLoaderComponent
     */
    ngOnInit(): void;
    /**
     * Subscribe to `resize` window event observable
     * and run callback
     *
     * @memberof VideoLoaderComponent
     */
    ngAfterViewInit(): void;
    /**
     * If element is in viewport preload video by setting the src
     * of the dummy video element.
     *
     * @memberof VideoLoaderComponent
     */
    onInViewportChange(inViewport: boolean): void;
    /**
     * On width change, determine if device has changed and
     * reset directive
     *
     * @memberof VideoLoaderComponent
     */
    onWidthChange(width: number): void;
    /**
     * Set poster on image load
     *
     * @memberof VideoLoaderComponent
     */
    onImageLoad($event: ImageLoadedEvent): void;
    /**
     * Set loaded to true when video has been loaded
     *
     * @memberof VideoLoaderComponent
     */
    onVideoLoad(): void;
    /**
     * Trigger video preload if element is within viewport
     * and hasn't been preloaded
     *
     * @memberof VideoLoaderComponent
     */
    loadVideo(): void;
    /**
     * Trigger `ngUnsubscribe` complete on
     * component destroy lifecycle hook
     *
     * @memberof VideoLoaderComponent
     */
    ngOnDestroy(): void;
}
